gsl: The GNU Scientific Library
===============================

Description
-----------

The GNU Scientific Library

Website: http://www.gnu.org/software/gsl/

From the website above: The GNU Scientific Library (GSL) is a numerical
library for C and C++ programmers. It is free software under the GNU
General Public License.

The library provides a wide range of mathematical routines such as
random number generators, special functions and least-squares fitting.
There are over 1000 functions in total with an extensive test suite. If
the variable SAGE_CHECK is exported to the value "yes" when building
Sage, GSL's test suite is run.

License
-------

-  GPL V3


Upstream Contact
----------------

-  http://www.gnu.org/software/gsl/

GSL mailing lists:

-  Bug-gsl <bug-gsl@gnu.org> mailing list -- bug reports for the GNU
   Scientific Library should be sent to bug-gsl@gnu.org

-  Help-gsl <help-gsl@gnu.org> users mailing list -- for questions about
   installation, how GSL works and how it is used, or general questions
   concerning GSL.

-  Info-gsl <info-gsl@gnu.org> mailing list -- announcements of new
   releases
   are made there.

Special Update/Build Instructions
---------------------------------
